/**********************************************************************
File : cmdln.h
Date : /01/17/94
ANSI C
J.-P. Kuska
scanning the command line of a C program in a convinent way
***********************************************************************/

#define CMD_SWITCH   1
#define CMD_INTEGER  2
#define CMD_DOUBLE   3
#define CMD_STRING   4

/********************************************************************** 
the basic data structure
a classic linear list
***********************************************************************/

typedef struct CmdArgLst { 
                     struct CmdArgLst *next;
                     char *CmdLetter;
                     int What;
                     int ArgumentGiven;
                     void *DataPtr;
                     char *HelpTxt; }  CmdArgLst; 

/**********************************************************************/

CmdArgLst *DeclareCmdArg(char *cmd_switch, 
                         int data_type,
                         void *data,
                         char *help);
/*************************************************************
This function produces one entry in the list of
commandline switches. 

cmd_switch     is a string (even if the switch only contain one 
               character) indicating the command line argument.
data_type      can be one of the following values
               CMD_SWITCH, CMD_INTEGER, CMD_DOUBLE, CMD_STRING
               the form of the command line argument is for 
               CMD_SWITCH   +<switch> for on and -<switch> for
               off, in all other cases the form is
               -<switch> <argument>.
data           a pointer to the variable needed to store the
               argument of the switch or TRUE or FALSE
               for the data have to point to
               CMD_SWITCH, CMD_INTEGER  *data  <== & int
               CMD_DOUBLE               *data  <== & double
               CMD_STRING               *data  <== & char
help           is a string that contains a short explanation of the
               meaning of the switch.

**************************************************************/
    

CmdArgLst *AppendCmdArg(CmdArgLst *new_cmd, CmdArgLst *lst);
/************************************************************
Add new_cmd to the list lst of possible command line switches.
*************************************************************/

void HelpCmdArg(char *banner,
                CmdArgLst *lst);
/*************************************************************
Print the banner and the help information in the list of
command line switches. If the DEBUG directive is given to
the preprocessor than a detailed information about the paramter
scanned ist also printed.
**************************************************************/

int AnyCommandGiven(CmdArgLst *lst);
/*********************************************************************
 After the call of ScanCommandline this function returns TRUE when any
 command line argument is set by the user otherwise it returns 
FALSE.
**********************************************************************/

int CmdArgGiven(char *cmd_letter, CmdArgLst *lst);
/*********************************************************************
 Ask for a certain switch cmd_letter if it is given.
   CmdArgGiven can only called when ScanCommandline
   is finished. It returns TRUE if the command line argument
   -cmd_letter was given otherwise FALSE.
**********************************************************************/

CmdArgLst *ScanCommandline(CmdArgLst *lst, int argc, char *argv[]);
/********************************************************************
This is the true working horse - after the declaration of all possible
command line switches ScanCommandline assign the given arguments and
switches due to the lst. argc and argv are the same as in the head of main.
*********************************************************************/

CmdArgLst *RemoveCmdArgs(CmdArgLst *lst);
/************************************************************
Destroy the complede list of defined command line switches,
is is typical used when the command line is scanned and 
the memory used by lst can be returned to the system.
*************************************************************/
